==> manage-3.1.0-36.jar: management/sqls/sale/businessquery/handplanQuery.sql <==
select * from (
  select
    h.*,
	h1.*,
	s.f_operate_date,
    tu.f_paper_account,
    hd.f_stair1amount,hd.f_stair1price,hd.f_stair1fee,
    hd.f_stair2amount,hd.f_stair2price,hd.f_stair2fee,
    hd.f_stair3amount,hd.f_stair3price,hd.f_stair3fee,
    ua.f_zones
  from t_handplan h
  left join (select id,f_operate_date from t_sellinggas) s on s.id = h.f_sell_id
  left join (
      select f_hand_id f_hand_id,
             sum(case f_price_name when '阶梯1' then f_gas  when '固定气价' then f_gas else 0 end) f_stair1amount,
             sum(case f_price_name when '阶梯1' then f_price when '固定气价' then f_price else 0 end) f_stair1price,
             sum(case f_price_name when '阶梯1' then f_money when '固定气价' then f_money else 0 end) f_stair1fee,
             sum(case f_price_name when '阶梯2' then f_gas else 0 end) f_stair2amount,
             sum(case f_price_name when '阶梯2' then f_price else 0 end) f_stair2price,
             sum(case f_price_name when '阶梯2' then f_money else 0 end) f_stair2fee,
             sum(case f_price_name when '阶梯3' then f_gas else 0 end) f_stair3amount,
             sum(case f_price_name when '阶梯3' then f_price else 0 end) f_stair3price,
             sum(case f_price_name when '阶梯3' then f_money else 0 end) f_stair3fee
      from t_chargeprice where f_hand_id is not null group by f_hand_id
    ) hd on hd.f_hand_id=h.id
	left join (
		select f_hand_id,sum(f_charge_money) f_charge_money,sum(f_debt_money) f_debt_money  from t_sellinghand where f_state='有效' group by f_hand_id
	) h1 on h.id = h1.f_hand_id
    left join (select f_slice_area as f_zones,f_userinfo_id from t_user_address ) ua on h.f_userinfo_id= ua.f_userinfo_id
    left join t_userinfo tu on h.f_userinfo_id= tu.f_userinfo_id
) t
where {condition} order by f_hand_date desc

==> manage-3.1.0-39.jar: management/sqls/sale/businessquery/handplanQuery.sql <==
select * from (
  select
    h.*,
	h1.*,
    case when h.f_hand_date<(datename(yy,h.f_hand_date) + '-' + datename(mm,h.f_hand_date) +'-26 00:00:00.000' )
           then  substring(convert(varchar(100),dateadd(month,-1,h.f_hand_date), 23),0,8)
         else substring(convert(varchar(100),h.f_hand_date, 23),0,8) end
      f_rest_date,
	s.f_operate_date,
    tu.f_paper_account,
    tu.f_user_phone,
    hd.f_stair1amount,hd.f_stair1price,hd.f_stair1fee,
    hd.f_stair2amount,hd.f_stair2price,hd.f_stair2fee,
    hd.f_stair3amount,hd.f_stair3price,hd.f_stair3fee,
    ua.f_zones
  from t_handplan h
  left join (select id,f_operate_date from t_sellinggas) s on s.id = h.f_sell_id
  left join (
      select f_hand_id f_hand_id,
             sum(case f_price_name when '阶梯1' then f_gas  when '固定气价' then f_gas else 0 end) f_stair1amount,
             sum(case f_price_name when '阶梯1' then f_price when '固定气价' then f_price else 0 end) f_stair1price,
             sum(case f_price_name when '阶梯1' then f_money when '固定气价' then f_money else 0 end) f_stair1fee,
             sum(case f_price_name when '阶梯2' then f_gas else 0 end) f_stair2amount,
             sum(case f_price_name when '阶梯2' then f_price else 0 end) f_stair2price,
             sum(case f_price_name when '阶梯2' then f_money else 0 end) f_stair2fee,
             sum(case f_price_name when '阶梯3' then f_gas else 0 end) f_stair3amount,
             sum(case f_price_name when '阶梯3' then f_price else 0 end) f_stair3price,
             sum(case f_price_name when '阶梯3' then f_money else 0 end) f_stair3fee
      from t_chargeprice where f_hand_id is not null group by f_hand_id
    ) hd on hd.f_hand_id=h.id
	left join (
		select f_hand_id,sum(f_charge_money) f_charge_money,sum(f_debt_money) f_debt_money  from t_sellinghand where f_state='有效' group by f_hand_id
	) h1 on h.id = h1.f_hand_id
    left join (select f_slice_area as f_zones,f_userinfo_id from t_user_address ) ua on h.f_userinfo_id= ua.f_userinfo_id
    left join t_userinfo tu on h.f_userinfo_id= tu.f_userinfo_id
) t
where {condition} order by f_hand_date desc
